==> appinsights-0.11.11.tar.gz: appinsights-0.11.11/tests/applicationinsights_tests/channel_tests/contracts_tests/TestAvailabilityData.py <==
import unittest
import datetime
import uuid
import sys
import json

import sys, os, os.path
root_directory = os.path.join(os.path.dirname(os.path.realpath(__file__)), '..', '..', '..', '..')
if root_directory not in sys.path:
    sys.path.append(root_directory)

from applicationinsights.channel.contracts import AvailabilityData
from .Utils import TestJsonEncoder


class TestAvailabilityData(unittest.TestCase):
    def test_construct(self):
        item = AvailabilityData()
        self.assertNotEqual(item, None)
    
    def test_ver_property_works_as_expected(self):
        expected = 42
        item = AvailabilityData()
        item.ver = expected
        actual = item.ver
        self.assertEqual(expected, actual)
        expected = 13
        item.ver = expected
        actual = item.ver
        self.assertEqual(expected, actual)
    
    def test_id_property_works_as_expected(self):
        expected = 'Test string'
        item = AvailabilityData()
        item.id = expected
        actual = item.id
        self.assertEqual(expected, actual)
        expected = 'Other string'
        item.id = expected
        actual = item.id
        self.assertEqual(expected, actual)
    
    def test_name_property_works_as_expected(self):
        expected = 'Test string'
        item = AvailabilityData()
        item.name = expected
        actual = item.name
        self.assertEqual(expected, actual)
        expected = 'Other string'
        item.name = expected
        actual = item.name
        self.assertEqual(expected, actual)
    
    def test_duration_property_works_as_expected(self):
        expected = 'Test string'
        item = AvailabilityData()
        item.duration = expected
        actual = item.duration
        self.assertEqual(expected, actual)
        expected = 'Other string'
        item.duration = expected
        actual = item.duration
        self.assertEqual(expected, actual)
    
    def test_success_property_works_as_expected(self):
        expected = True
        item = AvailabilityData()
        item.success = expected
        actual = item.success
        self.assertEqual(expected, actual)
        expected = False
        item.success = expected
        actual = item.success
        self.assertEqual(expected, actual)

    def test_run_location_property_works_as_expected(self):
        expected = 'Test string'
        item = AvailabilityData()
        item.run_location = expected
        actual = item.run_location
        self.assertEqual(expected, actual)
        expected = 'Other string'
        item.run_location = expected
        actual = item.run_location
        self.assertEqual(expected, actual)

    def test_properties_property_works_as_expected(self):
        item = AvailabilityData()
        actual = item.properties
        self.assertNotEqual(actual, None)
    
    def test_measurements_property_works_as_expected(self):
        item = AvailabilityData()
        actual = item.measurements
        self.assertNotEqual(actual, None)
    
    def test_serialize_works_as_expected(self):
        item = AvailabilityData()
        item.ver = 42
        item.id = 'Test string'
        item.name = 'Test string'
        item.duration = 'Test string'
        item.success = True
        for key, value in {'key1': 'test value 1', 'key2': 'test value 2'}.items():
            item.properties[key] = value
        for key, value in {'key1': 3.1415, 'key2': 42.2}.items():
            item.measurements[key] = value
        actual = json.dumps(item.write(), separators=(',', ':'), cls=TestJsonEncoder)
        expected = '{"ver":42,"id":"Test string","name":"Test string","duration":"Test string","success":true,"properties":{"key1":"test value 1","key2":"test value 2"},"measurements":{"key1":3.1415,"key2":42.2}}'
        self.assertEqual(expected, actual)

==> appinsights-0.11.12.tar.gz: appinsights-0.11.12/tests/applicationinsights_tests/channel_tests/contracts_tests/TestAvailabilityData.py <==
from .Utils import TestJsonEncoder
from applicationinsights.channel.contracts import AvailabilityData
import unittest
import datetime
import uuid
import sys
import json

import sys
import os
import os.path
root_directory = os.path.join(os.path.dirname(
    os.path.realpath(__file__)), '..', '..', '..', '..')
if root_directory not in sys.path:
    sys.path.append(root_directory)


class TestAvailabilityData(unittest.TestCase):
    def test_construct(self):
        item = AvailabilityData()
        self.assertNotEqual(item, None)

    def test_ver_property_works_as_expected(self):
        expected = 42
        item = AvailabilityData()
        item.ver = expected
        actual = item.ver
        self.assertEqual(expected, actual)
        expected = 13
        item.ver = expected
        actual = item.ver
        self.assertEqual(expected, actual)

    def test_id_property_works_as_expected(self):
        expected = 'Test string'
        item = AvailabilityData()
        item.id = expected
        actual = item.id
        self.assertEqual(expected, actual)
        expected = 'Other string'
        item.id = expected
        actual = item.id
        self.assertEqual(expected, actual)

    def test_name_property_works_as_expected(self):
        expected = 'Test string'
        item = AvailabilityData()
        item.name = expected
        actual = item.name
        self.assertEqual(expected, actual)
        expected = 'Other string'
        item.name = expected
        actual = item.name
        self.assertEqual(expected, actual)

    def test_duration_property_works_as_expected(self):
        expected = 'Test string'
        item = AvailabilityData()
        item.duration = expected
        actual = item.duration
        self.assertEqual(expected, actual)
        expected = 'Other string'
        item.duration = expected
        actual = item.duration
        self.assertEqual(expected, actual)

    def test_success_property_works_as_expected(self):
        expected = True
        item = AvailabilityData()
        item.success = expected
        actual = item.success
        self.assertEqual(expected, actual)
        expected = False
        item.success = expected
        actual = item.success
        self.assertEqual(expected, actual)

    def test_run_location_property_works_as_expected(self):
        expected = 'Test string'
        item = AvailabilityData()
        item.run_location = expected
        actual = item.run_location
        self.assertEqual(expected, actual)
        expected = 'Other string'
        item.run_location = expected
        actual = item.run_location
        self.assertEqual(expected, actual)

    def test_properties_property_works_as_expected(self):
        item = AvailabilityData()
        actual = item.properties
        self.assertNotEqual(actual, None)

    def test_measurements_property_works_as_expected(self):
        item = AvailabilityData()
        actual = item.measurements
        self.assertNotEqual(actual, None)

    def test_serialize_works_as_expected(self):
        item = AvailabilityData()
        item.ver = 42
        item.id = 'Test string'
        item.name = 'Test string'
        item.duration = 'Test string'
        item.success = True
        for key, value in {'key1': 'test value 1', 'key2': 'test value 2'}.items():
            item.properties[key] = value
        for key, value in {'key1': 3.1415, 'key2': 42.2}.items():
            item.measurements[key] = value
        actual = json.dumps(item.write(), separators=(
            ',', ':'), cls=TestJsonEncoder)
        expected = '{"ver":42,"id":"Test string","name":"Test string","duration":"Test string","success":true,"properties":{"key1":"test value 1","key2":"test value 2"},"measurements":{"key1":3.1415,"key2":42.2}}'
        self.assertEqual(expected, actual)
